@@ -18,15 +18,16 @@ unless $page_data_source then
 end
 
 class WikiServlet < WEBrick::HTTPServlet::AbstractServlet
-	def initialize(*argv)
-		super(*argv)
-	end
-
 	def do_GET(req, res)
-		app = KakiRequestHandler.new($page_data_source, 'kaki');
-		app.theme_dir = $theme_dir
-		app.theme_base_url = $theme_base_url
-		header, body = app.main(req.meta_vars, req.query)
+		app = KakiRequestHandler.new($page_data_source, req.meta_vars, req.query);
+
+		app.template_dir = $template_dir if $template_dir
+		app.theme_dir = $theme_dir if $theme_dir
+		app.theme_base_url = $theme_base_url if $theme_base_url
+		app.main()
+		header = app.response_header
+		body = app.response_body
+
 		header.each(){ |key, value|
 			res[key] = value
 		}
@@ -37,7 +38,17 @@ class WikiServlet < WEBrick::HTTPServlet::AbstractServlet
 		do_GET(req, res)
 	end
 end
-server.mount("/", WikiServlet)
+
+class RedirectServlet < WEBrick::HTTPServlet::AbstractServlet
+	def do_GET(req, res)
+		res.set_redirect(WEBrick::HTTPStatus::MovedPermanently.new, '/kaki')
+	end
+	def do_POST(req, res) do_GET(req, res); end
+	def do_HEAD(req, res) do_GET(req, res); end
+end
+
+server.mount("/", RedirectServlet)
+server.mount("/kaki", WikiServlet)
 server.mount("/theme", WEBrick::HTTPServlet::FileHandler, "./theme")
 server.mount("/files", WEBrick::HTTPServlet::FileHandler, "./files")
 
