@@ -1048,6 +1048,7 @@ protected
 	def make_response_from_template(tmpl_file)
 		data[:sub_page] = self.sub_page()
 		data.update(self.site_common_data())
+		data[:server_time] = Time.now.to_data_hash
 
 		# template file path
 		tmpl_path = nil
@@ -1190,6 +1191,13 @@ end
 
 class Time
 	def to_data_hash
+		offset = self.utc_offset
+		flag = offset < 0 ? "-" : "+"
+		offset = offset.abs()
+		minutes = offset / 60 
+		hours = minutes / 60
+		minutes = minutes % 60
+		zone = sprintf("GMT%s%d:%02d", flag, hours, minutes)
 		{
 			:yyyy => self.strftime("%Y"),
 			:yy => self.strftime("%y"),
@@ -1202,6 +1210,7 @@ class Time
 			:aa => self.strftime("%a"),
 			:BB => self.strftime("%B"),
 			:bb => self.strftime("%b"),
+			:ZZ => zone,
 		}
 	end
 end
