@@ -84,7 +84,7 @@ class PageDataSource
 			version = $2
 		end
 		lang = nil
-		if page_name =~ /(.*)\.(..)$/ then
+		if page_name =~ /(.+)\.([A-Za-z][A-Za-z](-[A-Za-z][A-Za-z])?)$/ then
 			page_name = $1
 			lang = $2
 		end
